<template>
  <win-md class="stock-detail" :title="setting.title" @close="close" :width="'800px'" :loading="loading">
    <el-row :gutter="20">
      <el-col :span="8">
        <span>出库单号：</span>
        <span>{{ detail.businessFormCode }}</span>
      </el-col>
      <el-col :span="8">
        <span>出库仓库：</span>
        <span>{{ detail.warehouseName }}</span>
      </el-col>
      <el-col :span="8">
        <span>所属机构：</span>
        <span>{{ detail.agencyName }}</span>
      </el-col>
    </el-row>
    <el-row :gutter="20" style="margin-top: 20px">
      <el-col :span="8">
        <span>创建人：</span>
        <span>{{ detail.operatorName }}</span>
      </el-col>
      <el-col :span="8">
        <span>出库时间：</span>
        <span>{{ detail.dealTime | formatTime }}</span>
      </el-col>
    </el-row>
    <el-row v-if="detail.procureDoc" :gutter="20" style="margin-top: 20px">
      <el-col class="img-row" :span="24">
        <span>出库手续：</span>
        <div class="img-box"></div>
      </el-col>
    </el-row>
    <div class="goods-card" v-for="(goodsItem, goodsIndex) in detail.fromOutputGoods" :key="goodsIndex">
      <el-row :gutter="20">
        <el-col :span="8">
          <span>物品分类：</span>
          <span>{{ goodsItem.categoryName }}</span>
        </el-col>
        <el-col :span="8">
          <span>物品名称：</span>
          <span>{{ goodsItem.goodsName }}</span>
        </el-col>
      </el-row>
      <el-table :data="goodsItem.models" :stripe="true" style="margin-top: 20px">
        <el-table-column prop="baseGoodsModelsName" label="规格型号" align="center">
          <template slot-scope="scope">
            {{ scope.row.baseGoodsModelsName }}
          </template>
        </el-table-column>
        <el-table-column label="单位" align="center">
          <template slot-scope="scope">
            {{ scope.row.unit }}
          </template>
        </el-table-column>
        <el-table-column prop="counts" label="出库数量" align="center">
          <template slot-scope="scope">
            {{ scope.row.counts }}
          </template>
        </el-table-column>
        <el-table-column prop="counts" label="金额" align="center">
          <template slot-scope="scope">
            {{ scope.row.price * scope.row.counts | formatPrice}}
          </template>
        </el-table-column>
      </el-table>
    </div>
  </win-md>
</template>
<script>
import { outputDetail } from '@/api/stock/accessStock';
import winMd from '@/components/win/win-md';
import * as DateFormatter from '@/utils/DateFormatter';

export default {
  components: { winMd },

  props: {
    setting: {
      type: Object,
      default: () => {},
    },
  },
  data() {
    return {
      loading:true,
      detail: {
        categoryName: '',
        businessFormCode: '',
        goodsName: '',
        agencyId: '',
        agencyName: '',
        states: '',
        createName: '',
        fromOutputGoods: [],
      },
    };
  },
  filters: {
    formatTime(time) {
      if (!time) return;
      return DateFormatter.LongToDateTime(time);
    },
    formatPrice(price) {
      return price / 100
    }
  },
  created() {
    outputDetail({ id: this.setting.id }).then((res) => {
      this.detail = res;
      this.loading = false
    });
  },
  methods: {
    close() {
      this.$emit('close')
    },
  },
};
</script>
<style lang="scss" scoped>
@import url(../../index.scss);
</style>
